-------------------------------------------------
-- Rupture Tourney
-------------------------------------------------

RUPTURE_TOURNEY_SAVED = RUPTURE_TOURNEY_SAVED or {
	playerscale = 100,
	targetscale = 100,
	petscale = 100,
	focusscale = 100,
	partyscale = 100,
	vehiclescale = 100,	
	comboscale = 100,
	aura = 1,
	cursor = 1,
	texture = 0,
	bgtexture = 0,
	locked = 0,
}

-------------------------------------------------
-- Local Variables
-------------------------------------------------

local _G = getfenv(0)
local pairs = pairs
local ipairs = ipairs
local GetComboPoints = GetComboPoints
local classhex = function(class)
	return string.format("|cff%02x%02x%02x", RAID_CLASS_COLORS[class].r * 255, RAID_CLASS_COLORS[class].g * 255, RAID_CLASS_COLORS[class].b * 255)
end
local getinfo = function(unit, type)
	local curr, max, perc, r, g, b, MHfound
	curr = _G["Unit"..type](unit)
	max = _G["Unit"..type.."Max"](unit)
	perc = curr / max

	if type == "Health" then
		if perc > 0.5 then
			r = (1.0 - perc) * 2
			g = 1.0
		else
			r = 1.0
			g = perc * 2
		end
		b = 0.0
	end
	perc = format("%.0f", floor(perc * 100))
	return curr, max, perc, r, g, b
end
local castshow = function(bar)
	bar:ClearAllPoints()
	if UnitAura(bar.unit, 1) then
		bar:SetPoint("TOP", bar:GetParent(), "BOTTOM", 10, -18)
	else
		bar:SetPoint("TOP", bar:GetParent(), "BOTTOM", 10, -1)
	end
end
local castevent = function(self, event, tmpArg, ...)
	local newevent = event
	local newarg1 = tmpArg

	if event == "PLAYER_TARGET_CHANGED" or event == "PLAYER_FOCUS_CHANGED" then
        local nameChannel  = UnitChannelInfo(self.unit)
		local nameSpell  = UnitCastingInfo(self.unit)

        if event == "PLAYER_TARGET_CHANGED" then
            newarg1 = "target"
        else
            newarg1 = "focus"
        end
		if nameChannel then
			newevent = "UNIT_SPELLCAST_CHANNEL_START"
		elseif nameSpell then
			newevent = "UNIT_SPELLCAST_START"
		else
			self.casting = nil
			self.channeling = nil
			self:SetMinMaxValues(0, 0)
			self:SetValue(0)
			self:Hide()
			return
		end
	end
	CastingBarFrame_OnEvent(self, newevent, newarg1, ...)
end

-------------------------------------------------
-- Hide Default Frames
-------------------------------------------------

local HideDefaultFrame = function(self)
	self:UnregisterAllEvents()
	UnregisterUnitWatch(self)
	self:Hide()
end
HideDefaultFrame(PlayerFrame)
HideDefaultFrame(TargetFrame)
HideDefaultFrame(ComboFrame)
HideDefaultFrame(PetFrame)
HideDefaultFrame(FocusFrame)
for i = 1, 4 do
	local PartyFrame = _G["PartyMemberFrame"..i]
	HideDefaultFrame(PartyFrame)
end
ShowPartyFrame = function() return end

-------------------------------------------------
-- Update Functions
-------------------------------------------------

-- Update Auras
local Update_Auras = function(self)
	local button, count, name, rank, texture, app, cure, border, color, duration, left
	local debuffType, isMine, isStealable
	local helpful = "HELPFUL"
	local harmful = "HARMFUL"
	
	for i = 1, 10 do
		button = _G[self:GetName().."buff"..i]
		if not button then
			break
		end
		name, rank, texture, app, debuffType, duration, left, isMine, isStealable = UnitAura(self.unit, i, helpful)
		if name then
			_G[button:GetName().."Icon"]:SetTexture(texture)
			count = _G[button:GetName().."Count"]
			if app > 1 then
				count:SetText(app)
				count:Show()
			else
				count:Hide()
			end
			if duration and duration > 0 then
				CooldownFrame_SetTimer(_G[button:GetName().."Cooldown"], left-duration, duration, 1)
			else
				_G[button:GetName().."Cooldown"]:Hide()
			end
			button:Show()
		else
			button:Hide()
		end
	end

	for i = 1, 6 do
		button = _G[self:GetName().."debuff"..i]
		if not button then
			break
		end
		name, rank, texture, app, cure, duration, left, isMine, isStealable = UnitAura(self.unit, i, harmful)
		if name then
			_G[button:GetName().."Icon"]:SetTexture(texture)
			count = _G[button:GetName().."Count"]
			border = _G[button:GetName().."Border"]
			if app > 1 then
				count:SetText(app)
				count:Show()
			else
				count:Hide()
			end

			if cure then
				color = DebuffTypeColor[cure]
			else
				color = DebuffTypeColor["none"]
			end
			if duration and duration > 0 then
				CooldownFrame_SetTimer(_G[button:GetName().."Cooldown"], left-duration, duration, 1)
			else
				_G[button:GetName().."Cooldown"]:Hide()
			end
			border:SetVertexColor(color.r, color.g, color.b)
			button:Show()
		else
			button:Hide()
		end
	end

	local cast = _G[self:GetName().."SpellBar"]
	if cast then
		castshow(cast)
	end
end

-- Update Name
local Update_Name = function(self)
	local _, eclass = UnitClass(self.unit)
	local color = RAID_CLASS_COLORS[eclass] or { r = 1, g = 1, b = 1 }
	local name = UnitName(self.unit)
		self.name:SetText(name)
		self.name:SetTextColor(color.r, color.g, color.b)

	--[[if self.unit == "party1" then
		local binding = GetBindingText(GetBindingKey("TARGETPARTYMEMBER1"), "KEY_")
		self.name:SetText("|cffffffff["..binding.."] |r"..UnitName("party1"))
		self.name:SetTextColor(color.r, color.g, color.b)
		
	elseif self.unit == "party2" then
		local binding = GetBindingText(GetBindingKey("TARGETPARTYMEMBER2"), "KEY_")
		self.name:SetText("|cffffffff["..binding.."] |r"..UnitName("party2"))
		self.name:SetTextColor(color.r, color.g, color.b)
		
	elseif self.unit == "party3" then
		local binding = GetBindingText(GetBindingKey("TARGETPARTYMEMBER3"), "KEY_")
		self.name:SetText("|cffffffff["..binding.."] |r"..UnitName("party3"))
		self.name:SetTextColor(color.r, color.g, color.b)
		
	elseif self.unit == "party4" then
		local binding = GetBindingText(GetBindingKey("TARGETPARTYMEMBER4"), "KEY_")
		self.name:SetText("|cffffffff["..binding.."] |r"..UnitName("party4"))
		self.name:SetTextColor(color.r, color.g, color.b)
	end]]
end

-- Update Leader / LootMaster
local Update_Leader = function(self)
	local lootMethod
	local lootMaster
	lootMethod, lootMaster = GetLootMethod()
	
	-- Player
	if self.unit == "player" then
		if IsPartyLeader() then
			self.leader:Show()
		else
			self.leader:Hide()
		end				
		if lootMaster == 0 and ((GetNumPartyMembers() > 0 or GetNumRaidMembers() > 0)) then
			self.masterlooter:Show()
		else
			self.masterlooter:Hide()
		end
	end
	
	-- Party1
	if self.unit == "party1" then
		if GetPartyLeaderIndex() == 1 then
			self.leader:Show()
		else
			self.leader:Hide()
		end		
		if lootMaster == 1 and ((GetNumPartyMembers() > 0 or GetNumRaidMembers() > 0)) then
			self.masterlooter:Show()
		else
			self.masterlooter:Hide()
		end
	
	-- Party2
	elseif self.unit == "party2" then
		if GetPartyLeaderIndex() == 2 then
			self.leader:Show()
		else
			self.leader:Hide()
		end		
		if lootMaster == 2 and ((GetNumPartyMembers() > 0 or GetNumRaidMembers() > 0)) then
			self.masterlooter:Show()
		else
			self.masterlooter:Hide()
		end
		
	-- Party3
	elseif self.unit == "party3" then
		if GetPartyLeaderIndex() == 3 then
			self.leader:Show()
		else
			self.leader:Hide()
		end				
		if lootMaster == 3 and ((GetNumPartyMembers() > 0 or GetNumRaidMembers() > 0)) then
			self.masterlooter:Show()
		else
			self.masterlooter:Hide()
		end
	
	-- Party4
	elseif self.unit == "party4" then
		if GetPartyLeaderIndex() == 4 then
			self.leader:Show()
		else
			self.leader:Hide()
		end
				
		if lootMaster == 4 and ((GetNumPartyMembers() > 0 or GetNumRaidMembers() > 0)) then
			self.masterlooter:Show()
		else
			self.masterlooter:Hide()
		end
	end
	-- Target
	if self.unit == "target" then
		if UnitIsPartyLeader("target") then
			self.leader:Show()
		else
			self.leader:Hide()
		end
	end
end

-- Update Reaction
local Update_Reaction = function(self)		
		if UnitIsEnemy(self.unit, "player")  then
			self:SetBackdropBorderColor(1, 0, 0)
		elseif UnitIsUnit(self.unit, "player") or UnitIsUnit(self.unit, "pet") then
			self:SetBackdropBorderColor(1, 1, 0)
		elseif UnitInParty(self.unit) then
			self:SetBackdropBorderColor(0, 1, 0)
		else
			self:SetBackdropBorderColor(1, 1, 1)
		end	
end

-- Update Frame
local Update_Frame = function(self, notext)
	local curr, max, perc, r, g, b = getinfo(self.unit, "Health")
	self.hp:SetStatusBarColor(r, g, b)
	self.hp:SetMinMaxValues(0, max)
	self.hp:SetValue(curr)
	self.hpperc:SetText(perc.."%")
	self.hpperc:SetTextColor(r, g, b)
	if self.hptext then
	local miss = curr - max
		if miss < 0 then
			self.hpmiss:SetText(miss)
		else
			self.hpmiss:SetText(nil)
		end
		self.hptext:SetText(curr.."/"..max)
	end

	if self.mp then
		curr, max, perc = getinfo(self.unit, "Mana")
		self.mp:SetMinMaxValues(0, max)
		self.mp:SetValue(curr)
		self.mptext:SetText(curr.."/"..max)
		local color = PowerBarColor[UnitPowerType(self.unit)]
		self.mp:SetStatusBarColor(color.r, color.g, color.b)
		self.mpbg:SetVertexColor(color.r, color.g, color.b, 0.25)
	end

	if not notext then
		--updatename(self)
		Update_Name(self)	
	end
	--updateauras(self)
	Update_Auras(self)
	--updateleader(self)
	Update_Leader(self)
	Update_Reaction(self)
end

-- Update Target of Unit
local totupdate = function(self, e)
	local unit, notext
	unit = SecureButton_GetUnit(self)
	if UnitExists(unit) then
		notext = true
		if not self.lastname or self.lastname ~= UnitName(unit) then
			self.lastname = UnitName(unit)
			notext = nil
		end
		--updateframe(self, notext)
		Update_Frame(self, notext)
	else
		self.lastname = nil
	end
end

function Rupture_OnReceiveDrag(self)
	if self.unit == "player" then
		if CursorHasItem() then
			AutoEquipCursorItem()
		end
	end
end

-------------------------------------------------
-- Events
-------------------------------------------------

local events = {
	["PLAYER_ENTERING_WORLD"] = function(self, ...)
		--Update_Frame(self)
		Update_Frame(self)
	end,

	["PLAYER_TARGET_CHANGED"] = function(self, ...)
		if self.unit == "target" then
			--Update_Frame(self)
			Update_Frame(self)
		else
			if UnitName("target") == UnitName(self.unit) then
				self:LockHighlight()
			else
				self:UnlockHighlight()
			end
		end
	end,

	["PLAYER_FOCUS_CHANGED"] = function(self, ...)
		--Update_Frame(self)
		Update_Frame(self)
	end,

	["PARTY_LEADER_CHANGED"] = function(self)
		--Update_Frame(self)
		Update_Leader(self)
	end,

	["PARTY_MEMBERS_CHANGED"] = function(self, ...)
		--Update_Frame(self)
		Update_Frame(self)
	end,

	["UNIT_HEALTH"] = function(self, ...)
		local curr, max, perc, r, g, b = getinfo(self.unit, "Health")
		self.hp:SetStatusBarColor(r, g, b)
		self.hp:SetValue(curr)
		self.hptext:SetText(curr.."/"..max)
		local miss = curr - max
		if miss < 0 then
			self.hpmiss:SetText(miss)
		else
			self.hpmiss:SetText(nil)
		end
		self.hpperc:SetText(perc.."%")
		self.hpperc:SetTextColor(r, g, b)
	end,

	["UNIT_MAXHEALTH"] = function(self, ...)
		local curr, max, perc, r, g, b = getinfo(self.unit, "Health")
		self.hp:SetStatusBarColor(r, g, b)
		self.hp:SetMinMaxValues(0, max)
		self.hp:SetValue(curr)
		self.hptext:SetText(curr.."/"..max)
		self.hpperc:SetText(perc.."%")
		self.hpperc:SetTextColor(r, g, b)
	end,

	["UNIT_MANA"] = function(self, ...)
		local curr, max, perc = getinfo(self.unit, "Mana")
		self.mp:SetValue(curr)
		self.mptext:SetText(curr.."/"..max)
	end,

	["UNIT_MAXMANA"] = function(self, ...)
		local curr, max, perc = getinfo(self.unit, "Mana")
		self.mp:SetMinMaxValues(0, max)
		self.mp:SetValue(curr)
		self.mptext:SetText(curr.."/"..max)
	end,

	["UNIT_ENERGY"] = function(self, ...)
		local curr, max, perc = getinfo(self.unit, "Mana")
		self.mp:SetMinMaxValues(0, max)
		self.mp:SetValue(curr)
		self.mptext:SetText(curr.."/"..max)
	end,

	["UNIT_MAXENERGY"] = function(self, ...)
		local curr, max, perc = getinfo(self.unit, "Mana")
		self.mp:SetMinMaxValues(0, max)
		self.mp:SetValue(curr)
		self.mptext:SetText(curr.."/"..max)
	end,

	["UNIT_RAGE"] = function(self, ...)
		local curr, max, perc = getinfo(self.unit, "Mana")
		self.mp:SetMinMaxValues(0, max)
		self.mp:SetValue(curr)
		self.mptext:SetText(curr.."/"..max)
	end,

	["UNIT_MAXRAGE"] = function(self, ...)
		local curr, max, perc = getinfo(self.unit, "Mana")
		self.mp:SetMinMaxValues(0, max)
		self.mp:SetValue(curr)
		self.mptext:SetText(curr.."/"..max)
	end,

	["UNIT_FOCUS"] = function(self, ...)
		local curr, max, perc = getinfo(self.unit, "Mana")
		self.mp:SetMinMaxValues(0, max)
		self.mp:SetValue(curr)
		self.mptext:SetText(curr.."/"..max)
	end,

	["UNIT_MAXFOCUS"] = function(self, ...)
		local curr, max, perc = getinfo(self.unit, "Mana")
		self.mp:SetMinMaxValues(0, max)
		self.mp:SetValue(curr)
		self.mptext:SetText(curr.."/"..max)
	end,

	["UNIT_DISPLAYPOWER"] = function(self, ...)
		local curr, max, perc = getinfo(self.unit, "Mana")
		self.mp:SetMinMaxValues(0, max)
		self.mp:SetValue(curr)
		self.mptext:SetText(curr.."/"..max)
		local color = PowerBarColor[UnitPowerType(self.unit)]
		self.mp:SetStatusBarColor(color.r, color.g, color.b)
		self.mpbg:SetVertexColor(color.r, color.g, color.b, 0.25)
	end,

	["UNIT_NAME_UPDATE"] = function(self, ...)
		--updatename(self)
		Update_Name(self)
	end,

	--[[["UPDATE_BINDINGS"] = function(self)
		--updatename(self)
		Update_Frame(self)
	end,]]

	["UNIT_AURA"] = function(self, ...)
		--updateauras(self)
		Update_Auras(self)
	end,
	
	["UNIT_ENTERED_VEHICLE"] = function(self, ...)
	    --Update_Frame(self
	    Update_Frame(self)
	end,
	
	["UNIT_EXITING_VEHICLE"] = function(self, ...)
	    --Update_Frame(self
	    Update_Frame(self)
	end,
}

local onevent = function(self, event, ...)
	if UnitExists(self.unit) then
		if string.find(event, "^UNIT_") and arg1 ~= self.unit then
			return
		end
		events[event](self, ...)
	end
end

local units = {
	["player"] = {
		"PLAYER_ENTERING_WORLD",
		"PARTY_LEADER_CHANGED",
		"UNIT_HEALTH",
		"UNIT_MAXHEALTH",
		"UNIT_MANA",
		"UNIT_MAXMANA",
		"UNIT_ENERGY",
		"UNIT_MAXENERGY",
		"UNIT_RAGE",
		"UNIT_MAXRAGE",
		"UNIT_FOCUS",
		"UNIT_MAXFOCUS",
		"UNIT_DISPLAYPOWER",
		"UNIT_NAME_UPDATE",
		"UNIT_AURA",
	},
	["target"] = {
		"PLAYER_ENTERING_WORLD",
		"PLAYER_TARGET_CHANGED",
		"UNIT_HEALTH",
		"UNIT_MAXHEALTH",
		"UNIT_MANA",
		"UNIT_MAXMANA",
		"UNIT_ENERGY",
		"UNIT_MAXENERGY",
		"UNIT_RAGE",
		"UNIT_MAXRAGE",
		"UNIT_FOCUS",
		"UNIT_MAXFOCUS",
		"UNIT_DISPLAYPOWER",
		"UNIT_NAME_UPDATE",
		"UNIT_AURA",
	},
	["pet"] = {
		"PLAYER_ENTERING_WORLD",
		"UNIT_HEALTH",
		"UNIT_MAXHEALTH",
		"UNIT_MANA",
		"UNIT_MAXMANA",
		"UNIT_ENERGY",
		"UNIT_MAXENERGY",
		"UNIT_RAGE",
		"UNIT_MAXRAGE",
		"UNIT_FOCUS",
		"UNIT_MAXFOCUS",
		"UNIT_DISPLAYPOWER",
		"UNIT_NAME_UPDATE",
		"UNIT_AURA",
	},
	["focus"] = {
		"PLAYER_ENTERING_WORLD",
		"PLAYER_FOCUS_CHANGED",
		"UNIT_HEALTH",
		"UNIT_MAXHEALTH",
		"UNIT_MANA",
		"UNIT_MAXMANA",
		"UNIT_ENERGY",
		"UNIT_MAXENERGY",
		"UNIT_RAGE",
		"UNIT_MAXRAGE",
		"UNIT_FOCUS",
		"UNIT_MAXFOCUS",
		"UNIT_DISPLAYPOWER",
		"UNIT_NAME_UPDATE",
		"UNIT_AURA",
	},
	["party1"] = {
		"PLAYER_ENTERING_WORLD",
		"PLAYER_TARGET_CHANGED",
		"UNIT_HEALTH",
		"UNIT_MAXHEALTH",
		"UNIT_MANA",
		"UNIT_MAXMANA",
		"UNIT_ENERGY",
		"UNIT_MAXENERGY",
		"UNIT_RAGE",
		"UNIT_MAXRAGE",
		"UNIT_FOCUS",
		"UNIT_MAXFOCUS",
		"UNIT_DISPLAYPOWER",
		"PARTY_LEADER_CHANGED",
		"PARTY_MEMBERS_CHANGED",
		"UNIT_NAME_UPDATE",
		"UNIT_AURA",
		--"UPDATE_BINDINGS",
	},
	["party2"] = {
		"PLAYER_ENTERING_WORLD",
		"PLAYER_TARGET_CHANGED",
		"UNIT_HEALTH",
		"UNIT_MAXHEALTH",
		"UNIT_MANA",
		"UNIT_MAXMANA",
		"UNIT_ENERGY",
		"UNIT_MAXENERGY",
		"UNIT_RAGE",
		"UNIT_MAXRAGE",
		"UNIT_FOCUS",
		"UNIT_MAXFOCUS",
		"UNIT_DISPLAYPOWER",
		"PARTY_LEADER_CHANGED",
		"PARTY_MEMBERS_CHANGED",
		"UNIT_NAME_UPDATE",
		"UNIT_AURA",
		--"UPDATE_BINDINGS",
	},
	["party3"] = {
		"PLAYER_ENTERING_WORLD",
		"PLAYER_TARGET_CHANGED",
		"UNIT_HEALTH",
		"UNIT_MAXHEALTH",
		"UNIT_MANA",
		"UNIT_MAXMANA",
		"UNIT_ENERGY",
		"UNIT_MAXENERGY",
		"UNIT_RAGE",
		"UNIT_MAXRAGE",
		"UNIT_FOCUS",
		"UNIT_MAXFOCUS",
		"UNIT_DISPLAYPOWER",
		"PARTY_LEADER_CHANGED",
		"PARTY_MEMBERS_CHANGED",
		"UNIT_NAME_UPDATE",
		"UNIT_AURA",
		--"UPDATE_BINDINGS",
	},
	["party4"] = {
		"PLAYER_ENTERING_WORLD",
		"PLAYER_TARGET_CHANGED",
		"UNIT_HEALTH",
		"UNIT_MAXHEALTH",
		"UNIT_MANA",
		"UNIT_MAXMANA",
		"UNIT_ENERGY",
		"UNIT_MAXENERGY",
		"UNIT_RAGE",
		"UNIT_MAXRAGE",
		"UNIT_FOCUS",
		"UNIT_MAXFOCUS",
		"UNIT_DISPLAYPOWER",
		"PARTY_LEADER_CHANGED",
		"PARTY_MEMBERS_CHANGED",
		"UNIT_NAME_UPDATE",
		"UNIT_AURA",
		--"UPDATE_BINDINGS",
	},
	["vehicle"] = {
		"PLAYER_ENTERING_WORLD",
		"PLAYER_TARGET_CHANGED",
		"UNIT_HEALTH",
		"UNIT_MAXHEALTH",
		"UNIT_MANA",
		"UNIT_MAXMANA",
		"UNIT_ENERGY",
		"UNIT_MAXENERGY",
		"UNIT_RAGE",
		"UNIT_MAXRAGE",
		"UNIT_FOCUS",
		"UNIT_MAXFOCUS",
		"UNIT_DISPLAYPOWER",
		--"PARTY_LEADER_CHANGED",
		--"PARTY_MEMBERS_CHANGED",
		"UNIT_NAME_UPDATE",
		"UNIT_AURA",
		"UNIT_ENTERED_VEHICLE",
		"UNIT_EXITING_VEHICLE",
	}
}

-------------------------------------------------
-- Rupture Layout
-------------------------------------------------

for unit, events in pairs(units) do
	local frame = CreateFrame("Button", "Rupture_"..unit, UIParent, "SecureUnitButtonTemplate")

	-- Attributes
	frame.unit = unit
	frame:SetWidth(180)
	frame:SetHeight(50)
	frame:SetFrameStrata("LOW")
	frame:SetToplevel(true)
	frame:SetMovable(true)
	frame:EnableMouse(true)
	frame:EnableMouseWheel(true)
	frame:SetClampedToScreen(true)
	frame:RegisterForClicks("AnyUp")
	frame:RegisterForDrag("LeftButton")
	frame:SetBackdrop({
		bgFile = "Interface\\Tooltips\\UI-Tooltip-Background",
		edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
		tile = true,
		tileSize = 16,
		edgeSize = 16,
		insets = { left = 4, right = 4, top = 4, bottom = 4 },
	})
	frame:SetBackdropColor(0, 0, 0, 0.75)
	
	-- PlayerModel
	frame.child = CreateFrame("PlayerModel", "Rupture_"..unit.."Model", frame)
	frame.child:SetWidth(40)
	frame.child:SetHeight(40)
	frame.child:SetModelScale(1.9)
	frame.child:SetFrameStrata("LOW")
	frame.child:SetFrameLevel(1)
	frame.child:SetPoint("LEFT", 5, 0)
	frame.child:RegisterEvent("PLAYER_ENTERING_WORLD")
	frame.child:RegisterEvent("DISPLAY_SIZE_CHANGED")
	frame.child:RegisterEvent("UNIT_MODEL_CHANGED")
	if unit == "target" then
		frame.child:RegisterEvent("PLAYER_TARGET_CHANGED")
	elseif unit == "pet" then
		frame.child:RegisterEvent("UNI_PET")
	elseif unit == "focus" then
		frame.child:RegisterEvent("PLAYER_FOCUS_CHANGED")
	elseif found == 1 then
		frame.child:RegisterEvent("PARTY_MEMBERS_CHANGED")
	end
	frame.child.unit = unit
	frame.child:SetScript("OnEvent", function(self, event)
		if (event == "PLAYER_TARGET_CHANGED") then
   			if (UnitExists(self.unit)) then
	      		if (UnitIsVisible(self.unit)) then
	         		self:SetUnit(self.unit)
	         		self:Show()
	      		else
	         		self:Hide()
	      		end
	   		else
	       		self:Hide()
	   		end
		elseif (event == "DISPLAY_SIZE_CHANGED") then       
	    	self:RefreshUnit()   
		elseif (event == "UNIT_MODEL_CHANGED") then
		    self:RefreshUnit()
		else
	    	self:SetUnit(self.unit)
		end			
	end)
	frame.child:SetScript("OnUpdate", function(self) self:SetCamera(0) end)

	-- StatusBars / HP
	frame.hp = CreateFrame("StatusBar", "Rupture_"..unit.."HP", frame)
	frame.hp:SetWidth(130)
	frame.hp:SetHeight(15)
	frame.hp:SetPoint("TOPRIGHT", -5, -17)
	frame.hp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
	
	frame.hptext = frame.hp:CreateFontString(nil, "ARTWORK")
	frame.hptext:SetAllPoints(frame.hp)
	frame.hptext:SetJustifyH("LEFT")
	frame.hptext:SetFontObject("GameFontNormalSmall")
	frame.hptext:SetTextColor(1, 1, 1)

	frame.hpbg = frame.hp:CreateTexture(nil, "BACKGROUND")
	frame.hpbg:SetAllPoints(frame.hp)
	frame.hpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
	frame.hpbg:SetVertexColor(1, 0, 0, 0.25)

    frame.hpmiss = frame.hp:CreateFontString(nil, "ARTWORK")
	frame.hpmiss:SetAllPoints(frame.hp)
	frame.hpmiss:SetJustifyH("RIGHT")
	frame.hpmiss:SetFontObject("GameFontNormalSmall")
	frame.hpmiss:SetTextColor(1, 0.25, 0)

	frame.hpperc = frame.hp:CreateFontString(nil, "ARTWORK")
	frame.hpperc:SetWidth(125)
	frame.hpperc:SetJustifyH("RIGHT")
	frame.hpperc:SetFontObject("GameFontNormal")
	frame.hpperc:ClearAllPoints()
	frame.hpperc:SetPoint("TOPRIGHT", frame, -5, -5)

	-- StatusBars / MP
	frame.mp = CreateFrame("StatusBar", "Rupture_"..unit.."MP", frame)
	frame.mp:SetWidth(130)
	frame.mp:SetHeight(13)
	frame.mp:SetPoint("TOPRIGHT", _G["Rupture_"..unit.."HP"], "BOTTOMRIGHT", 0, -1)
	frame.mp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")

	frame.mptext = frame.mp:CreateFontString(nil, "ARTWORK")
	frame.mptext:SetAllPoints(frame.mp)
	frame.mptext:SetJustifyH("LEFT")
	frame.mptext:SetFontObject("GameFontNormalSmall")
	frame.mptext:SetTextColor(1, 1, 1)

	frame.mpbg = frame.mp:CreateTexture(nil, "BACKGROUND")
	frame.mpbg:SetAllPoints(frame.mp)
	frame.mpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
	frame.mpbg:SetVertexColor(1, 0, 0, 0.25)

	-- Name
	frame.name = frame.hp:CreateFontString(nil, "ARTWORK")
	frame.name:SetWidth(90)
	frame.name:SetHeight(12)
	frame.name:SetJustifyH("LEFT")
	frame.name:SetFontObject("GameFontNormal")
	frame.name:ClearAllPoints()
	frame.name:SetPoint("TOPLEFT", frame, 46, -4)

	-- Icons
	frame.leader = frame:CreateTexture(nil, "OVERLAY")
	frame.leader:SetWidth(13)
	frame.leader:SetHeight(13)
	frame.leader:SetTexture("Interface\\GroupFrame\\UI-Group-LeaderIcon")
	frame.leader:SetPoint("TOPLEFT", 6, -4)
	frame.leader:Hide()

	frame.masterlooter = frame:CreateTexture(nil, "OVERLAY")
	frame.masterlooter:SetWidth(13)
	frame.masterlooter:SetHeight(13)
	frame.masterlooter:SetTexture("Interface\\GroupFrame\\UI-Group-MasterLooter")
	frame.masterlooter:SetPoint("TOPLEFT", 6, -18)
	frame.masterlooter:Hide()

	-- Highlight
	local highlight = frame:CreateTexture(nil, "ARTWORK")
		highlight:SetWidth(130)
		highlight:SetHeight(14)
		highlight:SetPoint("TOPRIGHT", -3, -3)
		highlight:SetTexture("Interface\\QuestFrame\\UI-QuestTitleHighlight")
		highlight:SetBlendMode("ADD")
		highlight:Hide()
	frame:SetHighlightTexture(highlight)

	-- Buffs
	for i = 1, 10 do
		aura = CreateFrame("Button", "Rupture_"..unit.."buff"..i, frame, "RuptureTargetBuffButtonTemplate")
		aura.id = i
		aura.unit = unit
		aura.isaura = true
		aura:SetWidth(17)
		aura:SetHeight(17)
		aura:Hide()
		if i == 1 then
			aura:SetPoint("TOPLEFT", frame, "BOTTOMLEFT", 5, 2)
		else
			aura:SetPoint("LEFT", _G["Rupture_"..unit.."buff"..(i - 1)], "RIGHT", 0, 0)
		end

		aura:SetScript("OnEnter", function(self)
					GameTooltip:SetOwner(self, "ANCHOR_BOTTOMRIGHT", 0, 0);
					GameTooltip:SetUnitBuff(self.unit, self.id);
				end)
	end

	-- Debuffs
	for i = 1, 6 do
		aura = CreateFrame("Button", "Rupture_"..unit.."debuff"..i, frame, "RuptureTargetDebuffButtonTemplate")
		aura.id = i
		aura.unit = unit
		aura.isaura = true
		aura:SetWidth(18)
		aura:SetHeight(18)
		aura:Hide()
		_G["Rupture_"..unit.."debuff"..i.."Border"]:SetAllPoints(aura)
		if i == 1 then
			aura:SetPoint("TOPLEFT", frame, "TOPRIGHT", -2, -6)
		else
			if math.fmod(2, i) == 0 then
				aura:SetPoint("TOP", _G["Rupture_"..unit.."debuff"..(i - 1)], "BOTTOM", 0, -1)
			else
				aura:SetPoint("LEFT", _G["Rupture_"..unit.."debuff"..(i - 2)], "RIGHT", 0, 0)
			end
		end

		aura:SetScript("OnEnter", function(self)
					GameTooltip:SetOwner(self, "ANCHOR_BOTTOMRIGHT", 0, 0);
					GameTooltip:SetUnitDebuff(self.unit, self.id);
				end)
	end

	------------------------
	-- Additional Scripts --
	------------------------
	
	-- Regeneration Rates
    if (GetCVarBool("predictedPower") and unit == "player" or unit == "pet") then
		frame.mp:SetScript("OnUpdate", function(self)
			local currValue = UnitPower(unit, UnitPowerType(unit))
			if ( currValue ~= self.currValue ) then
				self:SetValue(currValue);
				self.currValue = currValue;
				frame.mptext:SetText(currValue.."/"..UnitPowerMax(unit, UnitPowerType(unit)))
			end
		end)
	end

    --Dropdown
    local dropdown, menufunc
	local id, found = string.gsub(unit, "party([1-4])", "%1")
	if found == 1 then
		dropdown = _G["PartyMemberFrame"..id.."DropDown"]
	else
		dropdown = _G[string.gsub(unit, "^%l", string.upper).."FrameDropDown"]
	end

	if dropdown then
		menufunc = function() ToggleDropDownMenu(1, nil, dropdown, "cursor") end
	end
	
    -- Register Events
	SecureUnitButton_OnLoad(frame, frame.unit, menufunc)
	RegisterUnitWatch(frame)
	
	-- Scripts
	frame:SetScript("OnLoad", function(self) Update_Frame(self) end)
	frame:SetScript("OnEvent", function(self, event, ...) onevent(self, event, ...) end)
	frame:SetScript("OnUpdate", function(self)
		--Update_
		Update_Reaction(self)
		Update_Leader(self)
	end)
	frame:SetScript("OnShow", function(self) Update_Frame(self) end)
	frame:SetScript("OnEnter", UnitFrame_OnEnter)
	frame:SetScript("OnLeave", UnitFrame_OnLeave)
	--frame:SetScript("OnDragStart", function(self) if IsShiftKeyDown() then self:StartMoving() end end)
	--frame:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
	frame:SetScript("OnReceiveDrag", function(self) Rupture_OnReceiveDrag(self) end)
	for _, event in ipairs(events) do
		frame:RegisterEvent(event)
	end

	--------------
	-- Position --
	--------------
	if not frame:IsUserPlaced() then
	    if unit == "player" then
			frame:SetPoint("CENTER", -337, 80)
		elseif unit == "target" then
		    frame:SetPoint("CENTER", -337, -2)
		elseif unit == "focus" then
		    frame:SetPoint("CENTER", 337, -2)
		else
		    frame:SetPoint("CENTER")
		end
	end
	
-------------------------------------------------
-- Target of Unit
-------------------------------------------------

if unit ~= "player" then
	local target = CreateFrame("Button", "Rupture_"..unit.."target", frame, "SecureUnitButtonTemplate")
	
	-- Attributes
	target.unit = unit.."target"
	target:SetWidth(129)
	target:SetHeight(19)
	target:RegisterForClicks("AnyUp")
	target:EnableMouse(true)
	target:SetClampedToScreen(true)
	target:SetPoint("BOTTOMLEFT", frame, "TOPLEFT", 3, -4)
	target:SetBackdrop({
		bgFile = "Interface\\Tooltips\\UI-Tooltip-Background",
		edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
		tile = true,
		tileSize = 14,
		edgeSize = 14,
		insets = { left = 5, right = 5, top = 5, bottom = 5 },
	})
	target:SetBackdropColor(0, 0, 0, 0.75)
	SecureUnitButton_OnLoad(target, target.unit, nil)
	RegisterUnitWatch(target)
	
	-- Statusbars / HP
	target.hp = CreateFrame("StatusBar", "Rupture_"..unit.."targetHP", target)
	target.hp:SetWidth(121)
	target.hp:SetHeight(12)
	target.hp:SetPoint("RIGHT", -4, 0)
	target.hp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")

	target.hpperc = target.hp:CreateFontString(nil, "ARTWORK")
	target.hpperc:SetAllPoints(target.hp)
	target.hpperc:SetJustifyH("RIGHT")
	target.hpperc:SetFontObject("GameFontNormalSmall")
	target.hpperc:SetTextColor(1, 1, 1)
	
	-- Name
	target.name = target.hp:CreateFontString(nil, "ARTWORK")
	target.name:SetWidth(90)
	target.name:SetHeight(12)
	target.name:SetJustifyH("LEFT")
	target.name:SetFontObject("GameFontNormalSmall")
	target.name:SetPoint("LEFT", 0, 0)

	target.update = 0
	target:SetScript("OnUpdate", function(self, arg1) totupdate(self, arg1) end)

	-- Debuffs
	for i = 1, 3 do
		aura = CreateFrame("Button", "Rupture_"..unit.."targetdebuff"..i, target, "RuptureTargetDebuffButtonTemplate")
		aura.id = i
		aura.isaura = true
		aura.unit = unit.."target"
		aura:SetWidth(15)
		aura:SetHeight(15)
		aura:Hide()
		_G["Rupture_"..unit.."targetdebuff"..i.."Border"]:SetAllPoints(aura)
		if i == 1 then
			aura:SetPoint("LEFT", target, "RIGHT", -1, 0)
		else
			aura:SetPoint("LEFT", _G["Rupture_"..unit.."targetdebuff"..(i - 1)], "RIGHT", 0, 0)
		end

		aura:SetScript("OnEnter", function(self)
					GameTooltip:SetOwner(self, "ANCHOR_BOTTOMRIGHT", 0, 0);
					GameTooltip:SetUnitDebuff(self.unit, self.id);
				end)
	end
end

-------------------------------------------------
-- Casting Bars
-------------------------------------------------	
if unit == "target" or unit == "focus" then
	local casting = CreateFrame("StatusBar", "Rupture_"..unit.."SpellBar", frame, "CastingBarFrameTemplate")
	casting:Hide()
	casting:SetWidth(150)
	casting:SetHeight(14)
	if unit == "target" then
		casting:RegisterEvent("PLAYER_TARGET_CHANGED")
	else
		casting:RegisterEvent("PLAYER_FOCUS_CHANGED")
	end
	
	this = casting
	CastingBarFrame_OnLoad(this, unit, false)
	_G["Rupture_"..unit.."SpellBarIcon"]:Show()
	
	local frameText = _G[this:GetName().."Text"]
	if frameText then
		frameText:SetTextHeight(10)
		frameText:ClearAllPoints()
		frameText:SetPoint("CENTER")
	end

	local frameBorder = _G[this:GetName().."Border"]
	if frameBorder then
		frameBorder:SetTexture("Interface\\CastingBar\\UI-CastingBar-Border-Small")
		frameBorder:SetWidth(197)
		frameBorder:SetHeight(60)
		frameBorder:ClearAllPoints()
		frameBorder:SetPoint("CENTER")
	end

	local frameFlash = _G[this:GetName().."Flash"]
	if frameFlash then
		frameFlash:SetTexture("Interface\\CastingBar\\UI-CastingBar-Flash-Small")
		frameFlash:SetWidth(197)
		frameFlash:SetHeight(49)
		frameFlash:ClearAllPoints()
		frameFlash:SetPoint("TOP", casting, "TOP", 0, 20)
	end

	casting:SetScript("OnShow", castshow)
	casting:SetScript("OnEvent", castevent)
	end
end

-------------------------------------------------
-- Combo Frame
-------------------------------------------------

local combo = CreateFrame("Frame", "Rupture_combo", UIParent)
	combo:SetWidth(30)
	combo:SetHeight(30)
    combo:SetFrameStrata("LOW")
    combo:SetClampedToScreen(true)
	combo:EnableMouse(true)
	combo:EnableMouseWheel(true)
	combo:SetMovable(true)
    combo:RegisterForDrag("LeftButton")
	combo:RegisterEvent("PLAYER_LOGIN")
	combo:RegisterEvent("UNIT_COMBO_POINTS")
	combo:RegisterEvent("PLAYER_TARGET_CHANGED")

	combo.text = combo:CreateFontString(nil,"OVERLAY")
	combo.text:SetPoint("CENTER", combo, "CENTER")
	combo.text:SetFont("Fonts\\FRIZQT__.TTF", 24, "OUTLINE")

	-- Scripts
	--combo:SetScript("OnDragStart", function(self) if IsShiftKeyDown() then self:StartMoving() end end)
	--combo:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
	combo:SetScript("OnEvent", function(self, event)
		if event == "PLAYER_LOGIN" then
			local class = select(2, UnitClass("player"))
			if class ~= "ROGUE" and class ~= "DRUID" then			
				self:Hide()
			end
		else
			combo.points = GetComboPoints("player","target")
			self.text:SetText(combo.points)
			
			if combo.points == 0 then
				self.text:SetTextColor(0, 1, 0)
			elseif combo.points == 1 then
				self.text:SetTextColor(0, 1, 0)
			elseif combo.points == 2 then
				self.text:SetTextColor(0, 1, 0)
			elseif combo.points == 3 then
				self.text:SetTextColor(1, 1, 0)
			elseif combo.points == 4 then
				self.text:SetTextColor(1, 1, 0)
			else
				self.text:SetTextColor(1, 0, 0)
			end
		end
	end)


	if not combo:IsUserPlaced() then
		combo:SetPoint("CENTER", UIParent)
	end
	

----------------
-- Clear Temp --
----------------

units = nil

-------------------------------------------------
-- Cooldowns
-------------------------------------------------

local cooldowntext = function(self)
	if self.cool then
		local remain = floor((self.start + self.duration) - GetTime())
		if remain >= 0 then
			if self.aura and not RUPTURE_TOURNEY_SAVED.aura then
				self.text:SetText(nil)
				self.cool = nil
				return
			end
			local scale = self:GetScale()
			local height = floor(22 / scale)
			local fheight = select(2, self.text:GetFont())
			local r, g, b = 1, 0, 0
			if remain >= 3600 then
				remain = math.floor(remain / 3600).."h"
				height = floor(14 / scale)
				r, g, b = 0.6, 0.6, 0.6
			elseif remain >= 60 then
				local min = math.floor(remain / 60)
				if self.aura then
					remain = min
				elseif min < 10 then
					local sec = math.floor(math.fmod(remain, 60))
					remain = string.format("%2d:%02s", min, sec)
				else
					remain = min.."m"
				end
				height = floor(14 / scale)
				r, g, b = 1, 1, 0
			end
			self.text:SetText(remain)
			self.text:SetTextColor(r, g, b)
			if not self.aura and (height ~= fheight) then
				if dpload then
                	self.text:SetFont(dpfont1, height, "OUTLINE")
				else
					self.text:SetFont("Fonts\\FRIZQT__.TTF", height, "OUTLINE")
				end
			end
		else
			self.text:SetText(nil)
			self.cool = nil
		end
	end
end

local cooldowns = function(this, start, duration, enable)
	if not this.text then
		this.text = this:CreateFontString(nil, "ARTWORK")
		this.text:SetPoint("CENTER")

		this.text:SetFont("Fonts\\FRIZQT__.TTF", (ceil(this:GetWidth() * 0.5 + 0.1)), "OUTLINE")

		this:SetScript("OnUpdate", function(self) cooldowntext(self) end)
		this.aura = this:GetParent().isaura
	end

	if not this.text:GetFont() then
		return
	end

	if start > 2 and duration > 2 then
		this.cool = true
		this.start = start
		this.duration = duration
	else
		this.cool = nil
		this.text:SetText(nil)
	end
end

hooksecurefunc("CooldownFrame_SetTimer", cooldowns)

-------------------------------------------------
-- Tooltip
-------------------------------------------------

local mousetot = function(self, e)
	self.update = self.update - e
	if self.update <= 0 then
		if self:IsUnit("mouseover") and UnitIsPlayer("mouseover") then
			local name = UnitName("mouseover")
			local class = select(2, UnitClass("mouseover"))
			local _, _, perc, r, g, b = getinfo("mouseover", "Health")
			GameTooltipTextLeft1:SetTextColor(r, g, b)
			GameTooltipTextLeft1:SetText(classhex(class)..name.. "|r ("..perc.."%)")
			if UnitExists("mouseovertarget") then
				name = UnitName("mouseovertarget")
				if UnitIsUnit("mouseovertarget", "player") then
					name = "|cffffffff"..YOU.."|r"
				else
					class = select(2, UnitClass("mouseovertarget"))
					name = classhex(class)..name.."|r"
				end
				local _, _, perc, r, g, b = getinfo("mouseovertarget", "Health")
				if not self.totline then
					self:AddLine("["..name.."]")
					self:Show()
					self.totline = self:NumLines()
				else
					local line = _G["GameTooltipTextLeft"..self.totline]
					line:SetTextColor(r, g, b)
					line:SetText("["..name.." ("..perc.."%)]")
					self:Show()
				end
			end
		end
	end
end

local settool = function(tooltip, parent)
	if tooltip == GameTooltip and parent == UIParent and UnitExists("mouseover") then
		if RUPTURE_TOURNEY_SAVED.cursor then
			tooltip:SetOwner(parent, "ANCHOR_CURSOR")
		end
		tooltip.totline = nil
	end
end

hooksecurefunc("GameTooltip_SetDefaultAnchor", settool)
GameTooltip.update = 0
GameTooltip:SetScript("OnUpdate", function (self, arg1) mousetot(self, arg1) end)

-------------------------------------------------
-- Options
-------------------------------------------------

local options = CreateFrame("Frame", "Rupture_options", UIParent)
options:SetWidth(700)
options:SetHeight(140)
options:SetFrameStrata("FULLSCREEN_DIALOG")
--options:SetClampedToScreen(true)
options:SetMovable(true)
options:RegisterForDrag("LeftButton")
options:EnableMouse(true)
--options:EnableMouseWheel(true)
options:SetBackdrop({
	bgFile = "Interface\\Tooltips\\UI-Tooltip-Background",
	edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
	tile = true,
	tileSize = 16,
	edgeSize = 16,
	insets = { left = 4, right = 4, top = 4, bottom = 4 },
})
options:SetBackdropColor(0, 0, 0, 0.75)
options:RegisterEvent("ADDON_LOADED")
options:RegisterEvent("VARIABLES_LOADED")
options:Hide()
table.insert(UISpecialFrames, "Rupture_options")
options:SetScript("OnDragStart", function(self) self:StartMoving() end)
options:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
options:SetScript("OnEvent", function()
		Rupture_player:SetScale(RUPTURE_TOURNEY_SAVED.playerscale /100)
		Rupture_target:SetScale(RUPTURE_TOURNEY_SAVED.targetscale /100)
		Rupture_pet:SetScale(RUPTURE_TOURNEY_SAVED.petscale /100)
		Rupture_focus:SetScale(RUPTURE_TOURNEY_SAVED.focusscale /100)
		Rupture_party1:SetScale(RUPTURE_TOURNEY_SAVED.partyscale /100)
		Rupture_party2:SetScale(RUPTURE_TOURNEY_SAVED.partyscale /100)
		Rupture_party3:SetScale(RUPTURE_TOURNEY_SAVED.partyscale /100)
		Rupture_party4:SetScale(RUPTURE_TOURNEY_SAVED.partyscale /100)
		Rupture_combo:SetScale(RUPTURE_TOURNEY_SAVED.comboscale /100)
		Rupture_vehicle:SetScale(RUPTURE_TOURNEY_SAVED.vehiclescale /100)
		
		Rupture_SetTexture()
		Rupture_SetBGTexture()
		
		if RUPTURE_TOURNEY_SAVED.locked == 1 then
    		Rupture_Locked()
    	else
	    	Rupture_Unlocked()
    	end
end)

if not options:IsUserPlaced() then
	options:SetPoint("TOP", UIParent, 0, -200)
end

local fontframe = CreateFrame("Frame", "Rupture_options_layer", Rupture_options)
fontframe:SetWidth(700)
fontframe:SetHeight(140)
fontframe:SetFrameStrata("LOW")
fontframe:SetPoint("TOPLEFT")

local font = fontframe:CreateFontString(nil, "ARTWORK")
font:SetWidth(700)
font:SetHeight(140)
font:SetPoint("CENTER", 0, 0)
font:SetAlpha(0.5)
font:SetFont("Fonts\\ARIALN.TTF", 30, "OUTLINE")
font:SetText("|cffff0000Rupture|r Tourney Menu")

check1 = CreateFrame("CheckButton", "Rupture_options_Lock", options, "UICheckButtonTemplate")
check1:SetWidth(20)
check1:SetHeight(20)
check1:SetPoint("TOPLEFT", options, "BOTTOMLEFT", 250, 27)
check1:SetScript("OnShow", function(self)
		self:SetChecked(RUPTURE_TOURNEY_SAVED.locked)
		getglobal(self:GetName().."Text"):SetText("Lock Frames")
	end)
check1:SetScript("OnClick", function(self)
		--RUPTURE_TOURNEY_SAVED.locked = self:GetChecked()
		PlaySound("igMainMenuOptionCheckBoxOn")

--<!-- fuckin strange -->
if RUPTURE_TOURNEY_SAVED.locked == 1 then
Rupture_Unlocked()
else
Rupture_Locked()
end

RUPTURE_TOURNEY_SAVED.locked = self:GetChecked()
	end)

check2 = CreateFrame("CheckButton", "Rupture_options_Tooltip", options, "UICheckButtonTemplate")
check2:SetWidth(20)
check2:SetHeight(20)
check2:SetPoint("TOPLEFT", options, "BOTTOMLEFT", 10, 27)
check2:SetScript("OnShow", function(self)
		self:SetChecked(RUPTURE_TOURNEY_SAVED.cursor)
		getglobal(self:GetName().."Text"):SetText("Tooltip at Cursor")
	end)
check2:SetScript("OnClick", function(self)
        PlaySound("igMainMenuOptionCheckBoxOn")
		RUPTURE_TOURNEY_SAVED.cursor = self:GetChecked()
	end)

check3 = CreateFrame("CheckButton", "Rupture_options_Aura", options, "UICheckButtonTemplate")
check3:SetWidth(20)
check3:SetHeight(20)
check3:SetPoint("TOPLEFT", options, "BOTTOMLEFT", 120, 27)
check3:SetScript("OnShow", function(self)
		self:SetChecked(RUPTURE_TOURNEY_SAVED.aura)
		getglobal(self:GetName().."Text"):SetText("Display CD on Auras")
	end)
check3:SetScript("OnClick", function(self)
		PlaySound("igMainMenuOptionCheckBoxOn")
		RUPTURE_TOURNEY_SAVED.aura = self:GetChecked()
	end)

------------
-- Bar1 --
------------

local bar = options:CreateTexture("Rupture_options_Bar1", "HIGH")
bar:SetPoint("TOPLEFT", 14, -14)
bar:SetWidth(200)
bar:SetHeight(20)
bar:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
bar:SetVertexColor(0, 1, 0, 1)
-- Slider
local slider = CreateFrame("Slider", "Rupture_options_Bar1_Slider", options, "RTextureSliderTemplate")
slider:SetPoint("TOPLEFT", 14, -40)
slider:EnableMouse(true)
slider:EnableMouseWheel(true)
slider:SetMinMaxValues(0, 20)
slider:SetValueStep(1)
-- OnShow
slider:SetScript("OnShow", function(self)
		self:SetValue(RUPTURE_TOURNEY_SAVED.texture)
		local value = self:GetValue()
		RUPTURE_TOURNEY_SAVED.texture = value
		--Rupture_SetTexture()
	if value == 0 then
		getglobal(self:GetName().."Text"):SetText("Default")
	else
		getglobal(self:GetName().."Text"):SetText("Status Bar Texture "..value)
 	end
	end)
-- OnValueChanged
slider:SetScript("OnValueChanged", function(self)
		local value = self:GetValue()
		RUPTURE_TOURNEY_SAVED.texture = value
		Rupture_SetTexture()
	if value == 0 then
		getglobal(self:GetName().."Text"):SetText("Default")
	else
		getglobal(self:GetName().."Text"):SetText("Status Bar Texture "..value)
 	end
end)
-- OnMouseWheel
slider:SetScript("OnMouseWheel", function(self)
	local s = self:GetScript("OnValueChanged")
	local newValue = self:GetValue() + (self:GetValueStep() * arg1)
	self:SetValue(newValue)
end)

------------
-- Bar2 --
------------

local bar = options:CreateTexture("Rupture_options_Bar2", "HIGH")
bar:SetPoint("TOPLEFT", 14, -64)
bar:SetWidth(200)
bar:SetHeight(20)
bar:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
bar:SetVertexColor(0, 1, 0, 1)
-- Slider
local slider = CreateFrame("Slider", "Rupture_options_Bar2_Slider", options, "RTextureSliderTemplate")
slider:SetPoint("TOPLEFT", 14, -90)
slider:EnableMouse(true)
slider:EnableMouseWheel(true)
slider:SetMinMaxValues(0, 20)
slider:SetValueStep(1)
-- OnShow
slider:SetScript("OnShow", function(self)
		self:SetValue(RUPTURE_TOURNEY_SAVED.bgtexture)
		local value = self:GetValue()
		RUPTURE_TOURNEY_SAVED.bgtexture = value
		--Rupture_SetTexture()
	if value == 0 then
		getglobal(self:GetName().."Text"):SetText("Default")
	else
		getglobal(self:GetName().."Text"):SetText("Background Bar Texture "..value)
 	end
	end)
-- OnValueChanged
slider:SetScript("OnValueChanged", function(self)
		local value = self:GetValue()
		RUPTURE_TOURNEY_SAVED.bgtexture = value
		Rupture_SetBGTexture()
	if value == 0 then
		getglobal(self:GetName().."Text"):SetText("Default")
	else
		getglobal(self:GetName().."Text"):SetText("Background Bar Texture "..value)
 	end
end)
-- OnMouseWheel
slider:SetScript("OnMouseWheel", function(self)
	local s = self:GetScript("OnValueChanged")
	local newValue = self:GetValue() + (self:GetValueStep() * arg1)
	self:SetValue(newValue)
end)

------------
-- Player --
------------

local slider = CreateFrame("Slider", "Rupture_PlayerScale", options, "RSliderTemplate")
slider:SetPoint("TOP", 90, -23)
slider:EnableMouse(true)
slider:EnableMouseWheel(true)
slider:SetMinMaxValues(25, 300)
slider:SetValueStep(1)
-- OnShow
slider:SetScript("OnShow", function(self)
		self:SetValue(RUPTURE_TOURNEY_SAVED.playerscale)
	end)
-- OnValueChanged
slider:SetScript("OnValueChanged", function(self)
		local value = self:GetValue()
		RUPTURE_TOURNEY_SAVED.playerscale = value
		Rupture_player:SetScale(value /100)
		getglobal(self:GetName().."Percentage"):SetText("|cffffffff"..value.."%|r");
	end)
-- OnEnter
slider:SetScript("OnEnter", function(self)
	getglobal(self:GetName().."Text"):SetText("|cffff0000Player Frame Scale|r")
end)
-- OnLeave
slider:SetScript("OnLeave", function(self)
	getglobal(self:GetName().."Text"):SetText("Player Frame Scale")
end)
-- OnMouseWheel
slider:SetScript("OnMouseWheel", function(self)
	local s = self:GetScript("OnValueChanged")
	local newValue = self:GetValue() + (self:GetValueStep() * arg1)
	self:SetValue(newValue)
end)
Rupture_PlayerScaleText:SetText("Player Frame Scale")

------------
-- Target --
------------

local slider = CreateFrame("Slider", "Rupture_TargetScale", options, "RSliderTemplate")
slider:SetPoint("TOPRIGHT", Rupture_PlayerScale, "BOTTOMRIGHT", 0, -23)
slider:EnableMouse(true)
slider:EnableMouseWheel(true)
slider:SetMinMaxValues(25, 300)
slider:SetValueStep(1)
-- OnShow
slider:SetScript("OnShow", function(self)
		self:SetValue(RUPTURE_TOURNEY_SAVED.targetscale)
	end)
-- OnValueChanged
slider:SetScript("OnValueChanged", function(self)
		local value = self:GetValue()
		RUPTURE_TOURNEY_SAVED.targetscale = value
		Rupture_target:SetScale(value /100)
		getglobal(self:GetName().."Percentage"):SetText("|cffffffff"..value.."%|r");
	end)
-- OnEnter
slider:SetScript("OnEnter", function(self)
	getglobal(self:GetName().."Text"):SetText("|cffff0000Target Frame Scale|r")
end)
-- OnLeave
slider:SetScript("OnLeave", function(self)
	getglobal(self:GetName().."Text"):SetText("Target Frame Scale")
end)
-- OnMouseWheel
slider:SetScript("OnMouseWheel", function(self)
	local s = self:GetScript("OnValueChanged")
	local newValue = self:GetValue() + (self:GetValueStep() * arg1)
	self:SetValue(newValue)
end)
Rupture_TargetScaleText:SetText("Target Frame Scale")

---------
-- Pet --
---------

local slider = CreateFrame("Slider", "Rupture_PetScale", options, "RSliderTemplate")
slider:SetPoint("TOPRIGHT", Rupture_TargetScale, "BOTTOMRIGHT", 0, -23)
slider:EnableMouse(true)
slider:EnableMouseWheel(true)
slider:SetMinMaxValues(25, 300)
slider:SetValueStep(1)
-- OnShow
slider:SetScript("OnShow", function(self)
		self:SetValue(RUPTURE_TOURNEY_SAVED.petscale)
	end)
-- OnValueChanged
slider:SetScript("OnValueChanged", function(self)
		local value = self:GetValue()
		RUPTURE_TOURNEY_SAVED.petscale = value
		Rupture_pet:SetScale(value /100)
		getglobal(self:GetName().."Percentage"):SetText("|cffffffff"..value.."%|r");
	end)
-- OnEnter
slider:SetScript("OnEnter", function(self)
	getglobal(self:GetName().."Text"):SetText("|cffff0000Pet Frame Scale|r")
end)
-- OnLeave
slider:SetScript("OnLeave", function(self)
	getglobal(self:GetName().."Text"):SetText("Pet Frame Scale")
end)
-- OnMouseWheel
slider:SetScript("OnMouseWheel", function(self)
	local s = self:GetScript("OnValueChanged")
	local newValue = self:GetValue() + (self:GetValueStep() * arg1)
	self:SetValue(newValue)
end)
Rupture_PetScaleText:SetText("Pet Frame Scale")

-----------
-- Focus --
-----------

local slider = CreateFrame("Slider", "Rupture_FocusScale", options, "RSliderTemplate")
slider:SetPoint("TOPLEFT", Rupture_PlayerScale, 170, 0)
slider:EnableMouse(true)
slider:EnableMouseWheel(true)
slider:SetMinMaxValues(25, 300)
slider:SetValueStep(1)
-- OnShow
slider:SetScript("OnShow", function(self)
		self:SetValue(RUPTURE_TOURNEY_SAVED.focusscale)
	end)
-- OnValueChanged
slider:SetScript("OnValueChanged", function(self)
		local value = self:GetValue()
		RUPTURE_TOURNEY_SAVED.focusscale = value
		Rupture_focus:SetScale(value /100)
		getglobal(self:GetName().."Percentage"):SetText("|cffffffff"..value.."%|r");
	end)
-- OnEnter
slider:SetScript("OnEnter", function(self)
	getglobal(self:GetName().."Text"):SetText("|cffff0000Focus Frame Scale|r")
end)
-- OnLeave
slider:SetScript("OnLeave", function(self)
	getglobal(self:GetName().."Text"):SetText("Focus Frame Scale")
end)
-- OnMouseWheel
slider:SetScript("OnMouseWheel", function(self)
	local s = self:GetScript("OnValueChanged")
	local newValue = self:GetValue() + (self:GetValueStep() * arg1)
	self:SetValue(newValue)
end)
Rupture_FocusScaleText:SetText("Focus Frame Scale")

-----------
-- Party --
-----------

local slider = CreateFrame("Slider", "Rupture_PartyScale", options, "RSliderTemplate")
slider:SetPoint("TOPRIGHT", Rupture_FocusScale, "BOTTOMRIGHT", 0, -23)
slider:EnableMouse(true)
slider:EnableMouseWheel(true)
slider:SetMinMaxValues(25, 300)
slider:SetValueStep(1)
-- OnShow
slider:SetScript("OnShow", function(self)
		self:SetValue(RUPTURE_TOURNEY_SAVED.partyscale)
	end)
-- OnValueChanged
slider:SetScript("OnValueChanged", function(self)
		local value = self:GetValue()
		RUPTURE_TOURNEY_SAVED.partyscale = value
		Rupture_party1:SetScale(value /100)
		Rupture_party2:SetScale(value /100)
		Rupture_party3:SetScale(value /100)
		Rupture_party4:SetScale(value /100)
		getglobal(self:GetName().."Percentage"):SetText("|cffffffff"..value.."%|r");
	end)
-- OnEnter
slider:SetScript("OnEnter", function(self)
	getglobal(self:GetName().."Text"):SetText("|cffff0000Party Frame Scale|r")
end)
-- OnLeave
slider:SetScript("OnLeave", function(self)
	getglobal(self:GetName().."Text"):SetText("Party Frame Scale")
end)
-- OnMouseWheel
slider:SetScript("OnMouseWheel", function(self)
	local s = self:GetScript("OnValueChanged")
	local newValue = self:GetValue() + (self:GetValueStep() * arg1)
	self:SetValue(newValue)
end)
Rupture_PartyScaleText:SetText("Party Frame Scale")

-------------
-- Vehicle --
-------------

local slider = CreateFrame("Slider", "Rupture_VehicleScale", options, "RSliderTemplate")
slider:SetPoint("TOPRIGHT", Rupture_PartyScale, "BOTTOMRIGHT", 0, -23)
slider:EnableMouse(true)
slider:EnableMouseWheel(true)
slider:SetMinMaxValues(25, 300)
slider:SetValueStep(1)
-- OnShow
slider:SetScript("OnShow", function(self)
		self:SetValue(RUPTURE_TOURNEY_SAVED.vehiclescale)
	end)
-- OnValueChanged
slider:SetScript("OnValueChanged", function(self)
		local value = self:GetValue()
		RUPTURE_TOURNEY_SAVED.vehiclescale = value
		Rupture_vehicle:SetScale(value /100)
		getglobal(self:GetName().."Percentage"):SetText("|cffffffff"..value.."%|r");
	end)
-- OnEnter
slider:SetScript("OnEnter", function(self)
	getglobal(self:GetName().."Text"):SetText("|cffff0000Vehicle Frame Scale|r")
end)
-- OnLeave
slider:SetScript("OnLeave", function(self)
	getglobal(self:GetName().."Text"):SetText("Vehicle Frame Scale")
end)
-- OnMouseWheel
slider:SetScript("OnMouseWheel", function(self)
	local s = self:GetScript("OnValueChanged")
	local newValue = self:GetValue() + (self:GetValueStep() * arg1)
	self:SetValue(newValue)
end)
Rupture_VehicleScaleText:SetText("Vehicle Frame Scale")

-------------
-- Vehicle --
-------------

local slider = CreateFrame("Slider", "Rupture_ComboScale", options, "RSliderTemplateSmall")
--slider:SetPoint("TOPRIGHT", Rupture_PartyScale, "BOTTOMRIGHT", 0, -23)
slider:SetPoint("TOPLEFT", options, 248, -23)
slider:EnableMouse(true)
slider:EnableMouseWheel(true)
slider:SetMinMaxValues(25, 300)
slider:SetValueStep(1)
-- OnShow
slider:SetScript("OnShow", function(self)
		self:SetValue(RUPTURE_TOURNEY_SAVED.comboscale)
	end)
-- OnValueChanged
slider:SetScript("OnValueChanged", function(self)
		local value = self:GetValue()
		RUPTURE_TOURNEY_SAVED.comboscale = value
		Rupture_combo:SetScale(value /100)
		getglobal(self:GetName().."Percentage"):SetText("|cffffffff"..value.."%|r");
	end)
-- OnEnter
slider:SetScript("OnEnter", function(self)
	getglobal(self:GetName().."Text"):SetText("|cffff0000Combo Frame Scale|r")
end)
-- OnLeave
slider:SetScript("OnLeave", function(self)
	getglobal(self:GetName().."Text"):SetText("Combo Frame Scale")
end)
-- OnMouseWheel
slider:SetScript("OnMouseWheel", function(self)
	local s = self:GetScript("OnValueChanged")
	local newValue = self:GetValue() + (self:GetValueStep() * arg1)
	self:SetValue(newValue)
end)
Rupture_ComboScaleText:SetText("Combo Frame Scale")

---------------------
-- Texture Options --
---------------------

function Rupture_SetTexture()
  local value = RUPTURE_TOURNEY_SAVED.texture
	if RUPTURE_TOURNEY_SAVED.texture == 0 then
		Rupture_options_Bar1:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_player.hp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_player.mp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_pet.hp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_pet.mp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_target.hp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_target.mp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_focus.hp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_focus.mp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party1.hp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party1.mp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party2.hp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party2.mp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party3.hp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party3.mp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party4.hp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party4.mp:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
	else
		Rupture_options_Bar1:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_player.hp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_player.mp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_pet.hp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_pet.mp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_target.hp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_target.mp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_focus.hp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_focus.mp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party1.hp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party1.mp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party2.hp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party2.mp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party3.hp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party3.mp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party4.hp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party4.mp:SetStatusBarTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
	end
end

function Rupture_SetBGTexture()
  local value = RUPTURE_TOURNEY_SAVED.bgtexture
	if RUPTURE_TOURNEY_SAVED.bgtexture == 0 then
		Rupture_options_Bar2:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_player.hpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_player.mpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_pet.hpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_pet.mpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_target.hpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_target.mpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_focus.hpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_focus.mpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party1.hpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party1.mpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party2.hpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party2.mpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party3.hpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party3.mpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party4.hpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
		Rupture_party4.mpbg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")
	else
		Rupture_options_Bar2:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_player.hpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_player.mpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_pet.hpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_pet.mpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_target.hpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_target.mpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_focus.hpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_focus.mpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party1.hpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party1.mpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party2.hpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party2.mpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party3.hpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party3.mpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party4.hpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
		Rupture_party4.mpbg:SetTexture("Interface\\AddOns\\Rupture_Tourney\\Textures\\Texture_"..value)
	end
end

local UF = {"Rupture_player", "Rupture_target", "Rupture_pet", "Rupture_focus", "Rupture_party1", "Rupture_party2", "Rupture_party3", "Rupture_party4", "Rupture_combo", "Rupture_vehicle"}

function Rupture_Locked()
   	for index,value in pairs(UF) do
    _G[value]:SetScript("OnDragStart", nil)
    _G[value]:SetScript("OnDragStop", nil)
    end
end

function Rupture_Unlocked()
   	for index,value in pairs(UF) do
	_G[value]:SetScript("OnDragStart", function(self) if IsShiftKeyDown() then self:StartMoving() end end)
    _G[value]:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
    end
end

--------------------
-- Slash Commands --
--------------------

SLASH_RUPTURE1	=	"/rt"
SLASH_RUPTURE2	=	"/rupture"
SLASH_RUPTURE3	=	"/rtourney"
SLASH_RUPTURE4	=	"/rupturetourney"

SlashCmdList["RUPTURE"] = function(msg)
msg = string.lower(msg)
	if Rupture_options:IsShown() then
		Rupture_options:Hide()
	else
		UIFrameFadeIn(Rupture_options, 0.3, 0, 1)
	end
end